@@ -107,7 +107,7 @@ class ObjectCounter(nn.Module):
         in_channels=3,
         num_classes=3,
         features=[16, 32],
-        fc_intermiate_size=10,
+        fc_intermediate_size=10,
         kernel_size=3,
         bias=True,
     ):
@@ -118,7 +118,7 @@ class ObjectCounter(nn.Module):
         self.in_channels = in_channels
         self.num_classes = num_classes
         self.features = features
-        self.fc_intermiate_size = fc_intermiate_size
+        self.fc_intermediate_size = fc_intermediate_size
         self.kernel_size = kernel_size
         self.bias = True
 
@@ -133,8 +133,8 @@ class ObjectCounter(nn.Module):
 
         self.pool = nn.MaxPool2d(kernel_size=2, stride=2)
         self.relu = nn.ReLU()
-        self.fc1 = nn.Linear(self.fc_in_size, self.fc_intermiate_size)
-        self.fc2 = nn.Linear(self.fc_intermiate_size, self.num_classes)
+        self.fc1 = nn.Linear(self.fc_in_size, self.fc_intermediate_size)
+        self.fc2 = nn.Linear(self.fc_intermediate_size, self.num_classes)
         self.feature_extractor = nn.ModuleList()
 
         # Feature extractor
