@@ -58,7 +58,7 @@ def show(imgs, figsize=(10.0, 10.0)):
     return None
 
 
-def add_labels(img, label, class_map, pred=False, object_count=False):
+def add_labels(img, label, class_map, pred=False, object_count=True):
     """Takes a single image of shape (3, H, W) and adds labels directly
     onto the image using cv2. Used with ImageSegmentation_DS/DM but can
     be used in other applicable computer vision tasks.
